pub struct SymbolInfo {
pub rva: u64,
pub base: u64,
pub size: u64,
pub name: String,
pub module: String,
pub lines: Vec<LineInfo>,
}Expand description
Information about a symbol in a PDB, including the member lines of the symbol, if any.
Fields
rva: u64The relative virtual address in the executable image
base: u64The base address of the executable image
size: u64The size of the symbol (e.g. function size)
name: StringThe (possibly mangled) name of the symbol
module: StringThe name of the module the symbol is in
lines: Vec<LineInfo>The source lines of code for the symbol
Implementations